@@ -3,7 +3,7 @@
  * Derived from
  * http://www.zip.com.au/~raf2/lib/software/daemon
  *
- * $Id: daemon.c,v 1.3 1999/11/03 19:26:33 nisse Exp $
+ * $Id: daemon.c,v 1.4 1999/12/12 19:33:56 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -47,27 +47,6 @@
 #include <sys/stat.h>
 #include <sys/socket.h>
 
-
-#if 0
-#include "msg.h"
-#include "prog.h"
-#include "sig.h"
-#include "mem.h"
-#include "err.h"
-#include "lim.h"
-#include "fifo.h"
-
-#ifdef NEEDS_SNPRINTF
-#include "snprintf.h"
-#endif
-
-static struct
-{
-	char *lock; /* Name of the locked pid file */
-}
-g;
-#endif
-
 #ifndef PID_DIR
 #define PID_DIR "/var/run"
 #endif
