@@ -1,6 +1,6 @@
 /* lsh_types.h
  *
- * $Id: lsh_types.h,v 1.33 1999/05/12 21:35:19 nisse Exp $ */
+ * $Id: lsh_types.h,v 1.35 1999/10/13 20:22:29 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -48,16 +48,27 @@
  
 #define UINT8 unsigned char
 
-#if __GNUC__ && HAVE_ATTRIBUTE
-#define NORETURN __attribute__ ((noreturn))
-#define PRINTF_STYLE(f, a) __attribute__ ((format(printf, f, a)))
-#define UNUSED __attribute__ ((unused))
+#if __GNUC__ && HAVE_GCC_ATTRIBUTE
+#define NORETURN __attribute__ ((__noreturn__))
+#define PRINTF_STYLE(f, a) __attribute__ ((__format__ (__printf__, f, a)))
+#define UNUSED __attribute__ ((__unused__))
 #else
 #define NORETURN
 #define PRINTF_STYLE(f, a)
 #define UNUSED
 #endif
 
+#if HAVE_GCC_FUNCTION
+#define FUNCTION_NAME __FUNCTION__
+#else
+#define FUNCTION_NAME "Unknown"
+#endif
+
+/* Stringizing macros */
+#define STRINGIZE1(x) #x
+#define STRINGIZE(x) STRINGIZE1(x)
+#define STRING_LINE STRINGIZE(__LINE__)
+
 #if HAVE_STRERROR
 #define STRERROR strerror
 #else
