@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.20 1999/11/29 21:32:49 nisse Exp $
+ * $Id: server_session.c,v 1.21 1999/12/12 19:34:08 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -797,10 +797,7 @@ do_spawn_shell(struct channel_request *c,
 	    argv0[0] = '-';
 	    strncpy (argv0 + 1, p, session->user->shell->length);
 	    debug("lshd: server.c: fixing up name of shell... done.\n");
-#if 0
-	    /* Not needed; shell and p should be NUL-terminated properly. */
-	    argv0[sizeof (argv0) - 1] = '\0';
-#endif	      
+
 	    execle(shell, argv0, NULL, env);
 	  }
 #else /* !USE_LOGIN_DASH_CONVENTION */
