@@ -8,27 +8,40 @@
 
 
 
-#line 26
+#line 16
 
 
-#line 30
 
 
-#line 34
+#line 33
 
 
-#line 62
+#line 37
+
+
+#line 65
     
 
 
-#line 67 "macros.m4"
+#line 84
 
-#line 69
+
+#line 102
+
+
+
+
+
+#line 109 "macros.m4"
+
+#line 111
 #include "lsh.h"
 
 #include "crypto.h"
 #include "digits.h"
 #include "format.h"
+#include "sexp.h"
+#include "spki.h"
 #include "xalloc.h"
 
 #include <assert.h>
@@ -504,7 +517,7 @@ int main(int argc UNUSED, char **argv UNUSED)
   }
 #line 27
 
-#line 64 "macros.m4"
+#line 106 "macros.m4"
 
   return 0;
 } 
\ No newline at end of file
