@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.h,v 1.20 1999/10/04 21:45:00 nisse Exp $ */
+ * $Id: werror.h,v 1.22 1999/10/25 20:11:42 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -41,7 +41,7 @@ void set_error_stream(int fd, int with_poll);
 void set_error_ignore(void);
 
 #ifdef HAVE_SYSLOG
-void set_error_syslog(void);
+void set_error_syslog(const char *id);
 #endif
 
 /* Format specifiers:
@@ -51,6 +51,7 @@ void set_error_syslog(void);
  * %c  int, interpreted as a single character to output
  * %n  mpz_t
  * %z  NUL-terminated string
+ * %a  Insert a string containing one atom.
  * %s  UINT32 length, UINT8 *data
  * %S  lsh_string *s
  *
